@@ -5,7 +5,9 @@ from . import __title__
 from .app_settings import (
     AA_DISCORDFORMATTER_ADDITIONAL_PING_TARGETS,
     AA_DISCORDFORMATTER_ADDITIONAL_FLEET_TYPES,
-    AA_DISCORDFORMATTER_ADDITIONAL_PING_WEBHOOKS
+    AA_DISCORDFORMATTER_ADDITIONAL_PING_WEBHOOKS,
+    get_site_url,
+    timezones_installed
 )
 
 
@@ -16,7 +18,9 @@ def index(request):
         'title': __title__,
         'additionalPingTargets': AA_DISCORDFORMATTER_ADDITIONAL_PING_TARGETS,
         'additionalFleetTypes': AA_DISCORDFORMATTER_ADDITIONAL_FLEET_TYPES,
-        'additionalPingWebhooks': AA_DISCORDFORMATTER_ADDITIONAL_PING_WEBHOOKS
+        'additionalPingWebhooks': AA_DISCORDFORMATTER_ADDITIONAL_PING_WEBHOOKS,
+        'site_url': get_site_url(),
+        'timezones_installed': timezones_installed()
     }
 
     return render(request, 'discordpingformatter/index.html', context)
